@@ -12,10 +12,22 @@ test_that("should have correct sample values", {
   lm.1    <- lm(y~xa+xb+xc+xd, data = d.f)
   set.seed(12345)
   bs.da.1 <- bootAverageDominanceAnalysis(lm.1, R=2)
-  expect_equivalent(names(bs.da.1),c("boot","preds","fit.functions","R","eg"))
+  expect_equivalent(names(bs.da.1),c("boot","preds","fit.functions","R","eg","terms"))
   expect_equivalent(bs.da.1$R,2)
   sum.bs.da.1<-summary(bs.da.1)
   expect_equal(colnames(sum.bs.da.1$r2),c("Var","Fit.Index","original","bs.E","bias","bs.SE"))
-  expect_equal(sum.bs.da.1$r2$Var, factor(c("xa","xb","xc","xd")))
+  expect_equal(sum.bs.da.1$r2$Var, c("xa","xb","xc","xd"))
   expect_output(print(sum.bs.da.1),"Resamples:  2")
 })
+
+test_that("should have correct values using terms",{
+
+  lm.mtcars<-lm(mpg~.,mtcars)
+  terms<-c(motor='cyl+disp+hp+carb',trans='drat+am+gear',other='wt+qsec+vs+am')
+  da.mtcars<-bootAverageDominanceAnalysis(lm.mtcars,R=2,terms=terms)
+  expect_equal(da.mtcars$terms,terms)
+  expect_equal(as.character(da.mtcars$eg[,1])   ,as.character(terms))
+
+  s.da<-summary(da.mtcars)
+  expect_equal(as.character(s.da$r2[,1]), as.character(names(terms)))
+})
\ No newline at end of file
